@@ -64,10 +64,10 @@ $simnetwork @themereports %simtitles %reporttitles %retrievedata
 @sweeps @miditers @varnumbers @caseseed @chanceseed @chancedata $dimchance $tee @pars_tocheck retrieve
 report newretrieve newreport washn
 $target %dowhat readsweeps $max_processes $computype $calcprocedure %specularratios @totalcases @winneritems
-toil genstar solvestar
+toil genstar solvestar integratebox integratebox__ filterbox__
 );
 
-$VERSION = '0.115';
+$VERSION = '0.127';
 $ABSTRACT = 'Sim::OPT is an optimization and parametric exploration program oriented to problem decomposition. It can be used with simulation programs receiving text files as input and emitting text files as output. It allows a free mix of sequential and parallel block coordinate searches.';
 
 #################################################################################
@@ -500,7 +500,8 @@ sub getblockelts
 { # IT GETS @blockelts. TO BE CALLED WITH getblockelts(\@sweeps, $countcase, $countblock)
 	my ( $sweeps_ref, $countcase, $countblock ) = @_;
 	my @sweeps = @{ $sweeps_ref };
-	my @blockelts = sort { $a <=> $b } @{ $sweeps[$countcase][$countblock] };
+	#my @blockelts = sort { $a <=> $b } @{ $sweeps[$countcase][$countblock] };
+	my @blockelts = @{ $sweeps[$countcase][$countblock] };
 	return ( \@blockelts );
 }
 
@@ -752,10 +753,10 @@ sub integratebox
 		my @elts = @{ $eltref };
 		my $target = $elts[0];
 		my $origin = $elts[3];
-		my @result = extractcase( $target, \%carrier );
-		my $righttarget = $result[0];
-		my @result = extractcase( $origin, \%carrier );
-		my $rightorigin = $result[0];
+		my @result1 = extractcase( $target, \%carrier );
+		my $righttarget = $result1[0];
+		my @result2 = extractcase( $origin, \%carrier );
+		my $rightorigin = $result2[0];
 		push (@newbox, [ $righttarget, $elts[1], $elts[2], $rightorigin, $elts[4] ] );
 		$c++;
 	}
@@ -799,6 +800,20 @@ sub filterbox
 }
 
 
+
+sub filterbox_delete
+{
+	my ( $arr_r ) = @_;
+	@arr = @{ $arr_r };
+	my @basket;
+	foreach my $case ( @arr )
+	{ $case->[0];
+		push ( @basket, $case->[0] );
+	}
+	return( @basket );
+}
+
+
 sub tellstring
 {
 	my ( $mids_ref, $file ) = @_;
@@ -1078,7 +1093,7 @@ sub solvestar
 	say $tee "IN SOLVESTAR \$dirfiles{starpositions}: " . dump( $dirfiles{starpositions} );
 	#say $tee "IN SOLVESTAR \$dirfiles{dummysweeps}: " . dump( $dirfiles{dummysweeps} );
 
-	$dirfiles{starnumber} = scalar( @{ $dirfiles{starpositions} } ); say $tee "AFTER \$dowhat{starnumber}: " . dump( $dowhat{starnumber} );
+	$dirfiles{starnumber} = scalar( @{ $digenstarrfiles{starpositions} } ); say $tee "AFTER \$dowhat{starnumber}: " . dump( $dowhat{starnumber} );
 
 	if ( not( scalar( @{ $dirfiles{starpositions} } ) == 0 ) )
 	{
@@ -1097,7 +1112,7 @@ sub callblock # IT CALLS THE SEARCH ON BLOCKS.
 	my $countcase = $d{countcase}; say $tee"IN callblock ( \$countcase) " . dump($countcase);
 	my $countblock = $d{countblock}; say $tee"IN callblock ( \$countblock) " . dump($countblock);
 	my @sweeps = @{ $d{sweeps} }; say $tee"IN callblock \@sweeps " . dump(@sweeps);
-	my @sourcesweeps = @{ $d{sourcesweeps} }; #say $tee"IN callblock \@sourcesweeps " . dump(@sourcesweeps);
+	my @sourcesweeps = @{ $d{sourcesweeps} }; say $tee"IN callblock \@sourcesweeps " . dump(@sourcesweeps);
 	my @miditers = @{ $d{miditers} }; #say $tee "IN callblock \@miditers " . dump( @miditers );
 	my @winneritems = @{ $d{winneritems} }; say $tee "IN callblock \@winneritems " . dump( @winneritems );
 	my %dirfiles = %{ $d{dirfiles} }; #say $tee "IN callblock \%dirfiles " . dump( %dirfiles );
@@ -1142,16 +1157,16 @@ sub callblock # IT CALLS THE SEARCH ON BLOCKS.
 
 	if ( $sourceblockelts[0] =~ />/ )
 	{ #say $tee "IN callblock IN: \$sourceblockelts[0] " . dump( $sourceblockelts[0] );
-		$dirfiles{starsign} = "yes"; say $tee "SETTING IN callblock: \$dirfiles{starsign} " . dump( $dirfiles{starsign} );
+		$dirfiles{starsign} = "yes"; #say $tee "SETTING IN callblock: \$dirfiles{starsign} " . dump( $dirfiles{starsign} );
 		$sourceblockelts[0] =~ /^(\d+)>/ ;
-		$dirfiles{stardivisions} = $1; say $tee "SETTING IN callblock : \$dirfiles{stardivisions} " . dump( $dirfiles{stardivisions} );
+		$dirfiles{stardivisions} = $1;
 	}
 	else
 	{
 		$dirfiles{starsign} = "no";
 		$dirfiles{stardivisions} = "";
 	} say $tee "IN callblock 3 \$dirfiles{starsign} " . dump( $dirfiles{starsign} );
-	#say $tee "IN callblock 3 \$dirfiles{stardivisions} " . dump( $dirfiles{stardivisions} );
+	say $tee "IN callblock 3 \$dirfiles{stardivisions} " . dump( $dirfiles{stardivisions} );
 
 
 	###########################################################
@@ -1166,7 +1181,7 @@ sub callblock # IT CALLS THE SEARCH ON BLOCKS.
 
 		%dirfiles = %{ solvestar( { dirfiles => \%dirfiles, dowhat => \%dowhat, varnumbers => \@varnumbers, blockelts => \@blockelts } ) };
 
-		my @newmiditers = @{ $dirfiles{starpositions} }; say $tee "IN2 callblock \@newmiditers " . dump( @newmiditers );
+		my @newmiditers = @{ $dirfiles{starpositions} }; #say $tee "IN2 callblock \@newmiditers " . dump( @newmiditers );
 		$dirfiles{miditershold} = dclone( \@miditers ); say $tee "IN2 callblock  \$dirfiles{miditershold} " . dump( $dirfiles{miditershold} );
 		@miditers = @{ dclone( \@newmiditers ) }; say $tee "IN2 callblock dcloned \@miditers " . dump( @miditers );
 		say $tee "IN2 callblock  \$dirfiles{starpositions} " . dump( $dirfiles{starpositions} );
@@ -1213,16 +1228,15 @@ sub deffiles # IT DEFINED THE FILES TO BE PROCESSED
 	#say $tee "IN DEFFILES \$dummyelt " . dump( $dummyelt );
 	say $tee "SO, \$c : " . dump( $c );
 
-
-	my $countcase = $d{countcase}; say $tee "IN DEFFILES \$countcase : " . dump( $countcase );
-  my $countblock = $d{countblock}; say $tee "IN DEFFILES \$countblock : " . dump( $countblock );
+	my $countcase = $d{countcase}; #say $tee "IN DEFFILES \$countcase : " . dump( $countcase );
+  my $countblock = $d{countblock}; #say $tee "IN DEFFILES \$countblock : " . dump( $countblock );
 	my @sweeps = @{ $d{sweeps} }; #say $tee "IN DEFFILES \@sweeps : " . dump( @sweeps );
 	my @sourcesweeps = @{ $d{sourcesweeps} }; #say $tee "IN DEFFILES \@sourcesweeps : " . dump( @sourcesweeps );
-	my @miditers = @{ $d{miditers} }; say $tee "IN DEFFILES \@miditers : " . dump( @miditers );
+	my @miditers = @{ $d{miditers} }; #say $tee "IN DEFFILES \@miditers : " . dump( @miditers );
 	my @winneritems = @{ $d{winneritems} }; #say $tee "\@winneritems : " . dump( @winneritems );
 	my %dirfiles = %{ $d{dirfiles} }; #say $tee "IN deffiles \%dirfiles " . dump( %dirfiles );
 	#$dirfiles{c} = $c; say $tee "SO, \$dirfiles{c} : " . dump( $dirfiles{c} );
-	say $tee "IN DEFFILES \$dirfiles{starsign} " . dump( $dirfiles{starsign} );
+	#say $tee "IN DEFFILES \$dirfiles{starsign} " . dump( $dirfiles{starsign} );
 	#say $tee "SO IN deffiles \$dirfiles{c} " . dump( $dirfiles{c} );
 	my %datastruc = %{ $d{datastruc} }; #say $tee "\%datastruc : " . dump( %datastruc );
 	my @varnumbers = @{ $d{varnumbers} }; #say $tee "IN DEFFILES \@varnumbers" . dump( @varnumbers );
@@ -1256,10 +1270,10 @@ sub deffiles # IT DEFINED THE FILES TO BE PROCESSED
 	sub toil
 	{
 		my ( $blockelts_r, $varnums_r, $basket_r, $c ) = @_;
-		my @blockelts = @{ $blockelts_r }; say $tee "IN TOIL \@blockelts : " . dump( @blockelts );
-		my %varnums = %{ $varnums_r }; say $tee "IN TOIL \%varnums : " . dump( %varnums );
+		my @blockelts = @{ $blockelts_r }; #say $tee "IN TOIL \@blockelts : " . dump( @blockelts );
+		my %varnums = %{ $varnums_r }; #say $tee "IN TOIL \%varnums : " . dump( %varnums );
 
-		my @basket = @{ $basket_r }; say $tee "IN TOIL \@basket : " . dump( @basket );
+		my @basket = @{ $basket_r }; #say $tee "IN TOIL \@basket : " . dump( @basket );
 		if ( ( $c eq "" ) or ( $c == 0 ) )
 		{
 			@box = ();
@@ -1268,19 +1282,21 @@ sub deffiles # IT DEFINED THE FILES TO BE PROCESSED
 		foreach my $var ( @blockelts )
 		{
 			my ( @bucket );
-			my $maxvalue	= $varnums{$var}; say $tee "IN TOIL \$maxvalue : " . dump( $maxvalue );
+			my $maxvalue	= $varnums{$var}; #say $tee "IN TOIL \$maxvalue : " . dump( $maxvalue );
 
 			foreach my $elt ( @basket )
 			{
 				my $root = $elt->[0]; #say $tee "IN TOIL \$root : " . dump( $root );
+				my $item;
 				my $cnstep = 1;
 				while ( $cnstep <= $maxvalue)
 				{	#say $tee "IN TOIL \$countblock : " . duvernummp( $countblock );
 					my $olditem = $root; #say $tee "IN TOIL \$olditem : " . dump( $olditem );
-					my $item = "$root" . "$var" . "-" . "$cnstep" . "_" ;  #say $tee "IN TOIL \$item : " . dump( $item );
-					push ( @bucket, [ $item, $var, $cnstep, $olditem, $c ] ); say $tee "IN TOIL \@bucket: " . dump( @bucket );
+					$item = "$root" . "$var" . "-" . "$cnstep" . "_" ;  #say $tee "IN TOIL \$item : " . dump( $item );
+					push ( @bucket, [ $item, $var, $cnstep, $olditem, $c ] ); #say $tee "IN TOIL \@bucket: " . dump( @bucket );
 					$cnstep++; #say $tee "IN TOIL \$cnstep : " . dump( $cnstep );
 				}
+				#push ( @bucket, [ $item, $var, $cnstep, $olditem, $c ] ); #say $tee "IN TOIL \@bucket: " . dump( @bucket );
 			}
 			@basket = ();
 			@basket = @bucket;
@@ -1303,8 +1319,8 @@ sub deffiles # IT DEFINED THE FILES TO BE PROCESSED
 		foreach my $elt ( @blockelts )
 		{
 			my @dummys = ( $elt );
-			my ( $box_r ) = toil( \@dummys, \%varnums, \@basket, $c );
-			my @bix = @{ $box_r }; #say $tee "IN DEFFILES2 \@bix: " . dump( @bix );
+			my @bix = @{ toil( \@dummys, \%varnums, \@basket, $c ) };
+			@bix = @{ $bix[0] };
 			push( @bux, @bix );
 			$c++;
 		}
@@ -1312,13 +1328,13 @@ sub deffiles # IT DEFINED THE FILES TO BE PROCESSED
 	else
 	{
 		#say $tee "DOING BOX \$dirfiles{starsign} : " . dump( $dirfiles{starsign} );
-			my ( $box_r ) = toil( \@blockelts, \%varnums, \@basket );
-			@bux = @{ $box_r };
-	} say $tee "IN DEFFILES2 \@box: " . dump( @box );
+			@bux = @{ toil( \@blockelts, \%varnums, \@basket ) };
+			@bux = @{ $bux[-1] };
+	} say $tee "IN DEFFILES2 \@bux: " . dump( @bux );
 	#say $tee "IN DEFFILES2 \$countblock : " . dump( $countblock );
 	#say $tee "IN DEFFILES \@blockelts : " . dump( @blockelts );
 
-	my $flattened_r = flattenbox( \@bux ); 	#say $tee "IN DEFFILES2 \$flattened_r: " . dump( $flattened_r );
+	#my $flattened_r = flattenbox( \@bux ); 	say $tee "IN DEFFILES2 \$flattened_r: " . dump( $flattened_r );
 
 	my $integrated_r;
 	if ( $dirfiles{starsign} eq "yes" )
@@ -1327,25 +1343,28 @@ sub deffiles # IT DEFINED THE FILES TO BE PROCESSED
 		my @bag;
 		foreach $mids_r ( @miditers )
 		{
-			%mids = %{ $mids_r }; say $tee "IN4 callblock \%mids" . dump( \%mids ); say $tee "IN callblock \$l" . dump( \$l );
-	 		$int_r = integratebox( $flattened_r, \%mids, $file ); #say $tee "IN DEFFILES2a \$integrated_r: " . dump( $integrated_r );
-			push( @bag, @{ $int_r } );
+			%mids = %{ $mids_r }; say $tee "IN DEFFILES \%mids" . dump( \%mids );
+	 		$integrated_r = integratebox( \@bux, \%mids, $file ); say $tee "IN DEFFILES2a \$integrated_r: " . dump( $integrated_r );
+			push( @bag, @{ $integrated_r } );
 			$l++;
 		}
 		$integrated_r = \@bag;
 	}
 	else
 	{
-		$integrated_r = integratebox( $flattened_r, \%mids, $file ); #say $tee "IN DEFFILES2b \$integrated_r: " . dump( $integrated_r );
+		$integrated_r = integratebox( \@bux, \%mids, $file ); say $tee "IN DEFFILES2b \$integrated_r: " . dump( $integrated_r );
 	}
 
-	my ( @finalbox ) = filterbox( $integrated_r ); say $tee "IN DEFFILES2 \@finalbox: " . dump( @finalbox );
+	my @finalbox = @{ $integrated_r }; say $tee "IN DEFFILES2 \@finalbox: " . dump( @finalbox );
+	my @finalbox = sort { $a->[0] <=> $b->[0] } @finalbox;
+	#my @finalbox = filterbox( $integrated_r );
+
 
 	my $datatowork =
 	{
 		countcase => $countcase, countblock => $countblock,
 		miditers => \@miditers,  winneritems => \@winneritems,
-		dirfiles => \%dirfiles, basket => @finalbox, # LEAVE @finalbox non-referenced! IT IS NOT A BUG.
+		dirfiles => \%dirfiles, basket => \@finalbox, # LEAVE @finalbox non-referenced! IT IS NOT A BUG.
 		sweeps => \@sweeps, sourcesweeps => \@sourcesweeps,
 		datastruc => \%datastruc, dowhat => \%dowhat,
 		varnumbers => \@varnumbers,
@@ -1391,17 +1410,17 @@ sub setlaunch # IT SETS THE DATA FOR THE SEARCH ON THE ACTIVE BLOCK.
 	#}
 
 	foreach my $elt ( @basket )
-	{	#say $tee "DOING";
-		my $newpars = $$elt[0];
-		my $countvar = $$elt[1];
-		my $countstep = $$elt[2];
-		my $oldpars = $$elt[3];
-		my $c = $$elt[4];
+	{	say $tee "DOING";
+		my $newpars = $elt->[0]; say $tee "IN SETLAUNCH \$newpars" . dump( $newpars );
+		my $countvar = $elt->[1]; say $tee "IN SETLAUNCH \$countvar" . dump( $countvar );
+		my $countstep = $elt->[2]; say $tee "IN SETLAUNCH \$countstep" . dump( $countstep );
+		my $oldpars = $elt->[3]; say $tee "IN SETLAUNCH \$oldpars" . dump( $oldpars );
+		my $c = $elt->[4]; say $tee "IN SETLAUNCH \$c" . dump( $c );
 
-		my @taken = extractcase("$newpars", \%mids);
+		my @taken = extractcase("$newpars", \%mids); say $tee "IN SETLAUNCH \@taken" . dump( @taken );
 		my $to = $taken[0]; say $tee "IN SETLAUNCH \$to" . dump( $to );
-		my @olds = extractcase( "$oldpars", \%mids);
-		my $origin = $olds[0]; #say $tee "IN SETLAUNCH \$origin" . dump( $origin );
+		my @olds = extractcase( "$oldpars", \%mids); say $tee "IN SETLAUNCH \@olds" . dump( @olds );
+		my $origin = $olds[0]; say $tee "IN SETLAUNCH \$origin" . dump( $origin );
 		push ( @instances,
 		{
 			countcase => $countcase, countblock => $countblock,
@@ -2014,6 +2033,8 @@ If the search has to start from more than one block in parallel, the first block
 
 The possibility of articulating a mix of parallel and sequential searches is of absolute importance, because it makes possible to design search structures with a depth, embodying precedence, and therefore procedural time, in them. Deriving from this, there is the fact that the representation tools in question are sufficient for describing directed graphs.
 
+With the aid of Sim::OPT::Interlinear, Sim::OPT can perform block coordinate descent on metamodels in place of all or some of the ordinary blocks of a block search. In that case, a configuration file for Interlinear should also be prepared.
+
 Where Sim::OPT may be fit for a task? Where a certain exploration is complex and/or when it is to be confronted through decomposition, by dividing a problem in overlapping subproblems; when there aren't slick tools suitable to decomposition-based, simulation-based optimization; when spednding a day, or two, or three setting up a model may spare months of work.
 
 Where it may not be suitable for the task? Due to the investment which is necessary for getting acquainted with its raw interface, for quick shots at small explorations.
