@@ -38,7 +38,7 @@ no warnings;
 #@EXPORT   = qw(); # our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw( descend ); # our @EXPORT = qw( );
 
-$VERSION = '0.81'; # our $VERSION = '';
+$VERSION = '0.85'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT::Descent is an module collaborating with the Sim::OPT module for performing block coordinate descent.';
 
 #########################################################################################
@@ -49,7 +49,6 @@ sub descend
 {
   $configfile = $main::configfile;
   %vals = %main::vals;
-
   #@pinmiditers = @main::pinmiditers;
 
   $mypath = $main::mypath;
@@ -67,6 +66,7 @@ sub descend
   #open( TOFILE, ">>$tofile" ) or die "Can't open $tofile: $!";
   $tee = new IO::Tee(\*STDOUT, ">>$tofile"); # GLOBAL ZZZ
   say $tee "\n#Now in Sim::OPT::Descend.\n";
+  #say $tee "IN ENTRY DESCEND4 \$file : " . dump( $file );
 
   %simtitles = %main::simtitles;
   %retrievedata = %main::retrievedata;
@@ -76,7 +76,7 @@ sub descend
   @varthemes_report = @main::varthemes_report;
   @varthemes_variations = @vmain::arthemes_variations;
   @varthemes_steps = @main::varthemes_steps;
-  @rankdata = @main::rankdata; # CUT ZZZ
+  @rankdata = @main::rankdata; # CUT ZZZSim::OPT::
   @rankcolumn = @main::rankcolumn;
   %reportdata = %main::reportdata;
   @report_loadsortemps = @main::report_loadsortemps;
@@ -120,7 +120,6 @@ sub descend
 	my %varnums = Sim::OPT::getcase( \@varnumbers, $countcase ); #say $tee "IN DEFFILES \%varnums" . dump( %varnums );
 	my %mids = Sim::OPT::getcase(\@miditers, $countcase); #say $tee "IN DEFFILES \%mids" . dump( %mids );
 
-
   my $direction = ${$dowhat{direction}}[$countcase][$countblock];
   my $starorder = ${$dowhat{starorder}}[$countcase][$countblock];
 
@@ -153,9 +152,13 @@ sub descend
   my $tottot = $dirfiles{tottot}; #say $tee "IN ENTRY DESCEND \$tottot: " . dump( $tottot );
   my $ordtot = $dirfiles{ordtot}; #say $tee "IN ENTRY DESCEND \$ordtot: " . dump( $ordtot );
 
+  my $confinterlinear = "$mypath/" . $dowhat{confinterlinear} ; say $tee "IN DESCEND5 \$confinterlinear: " . dump( $confinterlinear );
+
   my $repfile = $dirfiles{repfile}; say $tee "IN DESCEND \$repfile: " . dump( $repfile );
   if ( not( $repfile ) ){ die; }
   my $sortmixed = $dirfiles{sortmixed}; say $tee "IN DESCEND \$sortmixed: " . dump( $sortmixed );
+  my $metafile = $sortmixed . "_meta.csv" ;
+  my $ordmeta = $sortmixed . "_ordmeta.csv";
   if ( not( $sortmixed ) ){ die; }
 
   my ( $entryfile, $exitfile, $orderedfile );
@@ -182,7 +185,7 @@ sub descend
   my $orderedname = "$exitname" . "-ord";
   if ( $orderedname ne "" )
   {
-    $orderedfile = "$mypath/" . "$file" . "_" . "$orderedname" . ".csv";orderedfile
+    $orderedfile = "$mypath/" . "$file" . "_" . "$orderedname" . ".csv";
   }
   else
   {
@@ -960,7 +963,7 @@ sub descend
         if ( $starstring eq "" )
         {
           say "NOT DOING";
-          say RESPONSE "#N 0et number of instances: $netinstnum.\n" ;
+          say RESPONSE "#Net number of instances: $netinstnum.\n" ;
         }
         elsif ( $starstring ne "" )
         {
@@ -990,7 +993,149 @@ sub descend
         say RESPONSE "Descent directions: " . dump( $dowhat{direction} );
 
         {
-          ;#INSERT THE FUNCTION ON METAMODELS HERE
+
+
+          if ( $dowhat{metamodel} eq "yes" )#############PART ON METAODELS.
+          {
+            sub cleanres
+            {
+              my ( $sortmixed ) = @_;
+              open( ORDRES, "$sortmixed") or die;
+              my $cleanordres = $sortmixed . "-cleaned.csv";
+              my @lines = <ORDRES>;
+              close ORDRES;
+
+              open( CLEANORDRES, ">>$cleanordres" ) or die;
+              foreach my $line ( @lines )
+              {
+                $line =~ s/^$mypath\/$file// ;
+                $line =~ s/^_// ;
+                print CLEANORDRES $line;
+              }
+              close CLEANORDRES;
+              return( $cleanordres );
+            }
+
+            sub prepareblank
+            {
+              my ( $varnums_r, $blankfile, $blockelts_r, $bag_r, $file, $mids_r ) = @_;
+              my %varnums = %{ $varnums_r }; #say $tee "IN prepareblank \%varnums : " . dump( \%varnums );
+
+              open( BLANKFILE, ">$blankfile" ) or die;
+              #my @blockels = ( sort { $a <=> $b } ( keys %varnums ) ); say $tee "IN prepareblank1 \@blockels : " . dump( @blockels );
+              my @blockelts = ( sort { $a <=> $b } @{ $blockelts_r } ); #say $tee "IN prepareblank1 \@blockelts : " . dump( @blockelts );
+              my @box = @{ Sim::OPT::toil( \@blockelts, \%varnums, $bag_r ) }; #say $tee "IN prepareblank \@box : " . dump( @box );
+              my @obtaineds = @{ Sim::OPT::flattenbox( \@box ) }; #say $tee "IN prepareblank \@obtaineds : " . dump( @obtaineds );
+              my %mids = %{ $mids_r };
+              my $integrated_r = Sim::OPT::integratebox( \@obtaineds, \%mids, $file ); #say $tee "IN prepareblank \$integrated_r : " . dump( $integrated_r );
+
+              #my @finalbox; say $tee "IN LOOP \$file : " . dump( $file );
+
+              sub cleanthis
+              {
+                my ( $integrated_r, $mypath, $file ) = @_;
+                foreach my $el ( @{ $integrated_r } )
+                { #say $tee "IN LOOP \$el : " . dump( $el ); say $tee "IN LOOP \$el->[0] : " . dump( $el->[0] );
+                  $el->[0] =~ s/$mypath// ; #say $tee "IN LOOP \$el->[0] : " . dump( $el->[0] );
+                  $el->[0] =~ s/^\/// ; #say $tee "IN LOOP \$el->[0] : " . dump( $el->[0] );
+                  $el->[0] =~ s/^$file// ; #say $tee "IN LOOP \$el->[0] : " . dump( $el->[0] );
+                  $el->[0] =~ s/^_// ; #say $tee "IN LOOP \$e say $tee "IN LOOP \$el->[0] : " . dump( $el->[0] );l->[0] : " . dump( $el->[0] );
+                  $el->[0] =~ s/_$// ;
+                  push ( @finalbox, $el->[0] );
+                }
+                @finalbox = uniq( @finalbox );
+                #@finalbox = sort { $a <=> $b } @finalbox;
+                @finalbox = sort @finalbox;
+                return( @finalbox );
+              }
+
+              my @finalbox = cleanthis( $integrated_r, $mypath, $file );
+
+              foreach my $el ( @finalbox )
+              {
+                say BLANKFILE $el;
+              }
+              close BLANKFILE;
+            }
+
+
+            sub jointwo
+            {
+              my ( $cleanordres, $blankfile, $startfile ) = @_;
+              open( BLANKFILE, $blankfile ) or die;
+              my @blanklines = <BLANKFILE>;
+              close BLANKFILE;
+
+              open( CLEANORDRES, $cleanordres ) or die;
+              my @ordlines = <CLEANORDRES>;
+              close CLEANORDRES;
+
+              open( STARTFILE, ">$startfile" ) or die;
+
+              my @newarr;
+              foreach my $blankline ( @blanklines )
+              {
+                chomp $blankline;
+                my $signal = "no";
+                foreach my $ordline ( @ordlines )
+                {
+                  chomp $ordline;
+                  my @row = split( "," , $ordline );
+                  if ( $row[0] =~ /$blankline/ )
+                  {
+                    say STARTFILE "$blankline" . "," . "$row[1]" ;
+                    $signal = "yes";
+                  }
+                }
+                if ( $signal eq "no" )
+                {
+                  say STARTFILE $blankline ;
+                }
+              }
+              close STARTFILE;
+            }
+
+            sub givename { ;};
+
+            sub writefile { ;};
+
+            my $cleanordres = cleanres( $sortmixed ); #say $tee "IN TAKEOPTIMA1 \$cleanordres : " . dump( $cleanordres );
+            my $blankfile = "$sortmixed" . "_blank.csv";
+
+            my $bit = $file . "_";
+            my @bag =( $bit );
+            #say $tee "BEFORE prepareblank \%mids : " . dump( %mids );
+            prepareblank( $dirfiles{varnumbershold}->[0], $blankfile, \@blockelts, \@bag, $file, \%mids ) ;
+
+            my $startfile = $sortmixed . "_start.csv";
+            jointwo( $cleanordres, $blankfile, $startfile ) ;
+
+
+            say $tee "ABOUT TO LAUNCH INTERLINEAR";
+            Sim::OPT::Interlinear::interlinear( $confinterlinear, $startfile, $metafile, \@blockelts, $tofile );
+
+            open( METAFILE, "$metafile" ) or die "THERE IS NO METAFILE $metafile!\n";
+            my @totlines = <METAFILE>;
+            close METAFILE;
+
+            if ( ( $direction eq "<" ) or ( $starorder eq "<" ) )
+            {
+              @sorted = sort { (split( ',', $a))[ 1 ] <=> ( split( ',', $b))[ 1 ] } @totlines;
+            }
+            elsif ( ( $direction eq ">" ) or ( $starorder eq ">" ) )
+            {
+              @sorted = sort { (split( ',', $b))[ 1 ] <=> ( split( ',', $a))[ 1 ] } @totlines;
+            }
+
+            open( ORDMETA, ">>$ordmeta" ) or die;
+            foreach my $ln ( @sorted )
+            {
+              print ORDMETA $ln;
+            }
+            close ORDMETA;
+          } # END PART ON METAODELS.
+
+
         }
 
         $countblock = 0;
@@ -1003,6 +1148,7 @@ sub descend
 
         @varnumbers = @{ dclone( $dirfiles{varnumbershold} ) };
         @miditers = @{ dclone( $dirfiles{miditershold} ) };
+
         $dirfiles{starsign} = "no";
 
         Sim::OPT::callblock( { countcase => $countcase, countblock => $countblock,
@@ -1019,7 +1165,7 @@ sub descend
         $countstring++;
         $dirfiles{countstring} = $countstring;
 
-        push ( @{ $winneritems[$countcase][$countblock] }, $winneritem ); say $tee "TAKEOPTIMA->\@winneritems " . dump(@winneritems);
+        push ( @{ $winneritems[$countcase][$countblock] }, $winneritem ); #say $tee "TAKEOPTIMA->\@winneritems " . dump(@winneritems);
         say $tee "#Leaving case $countcase. Beginning with case " . ( plus1( $countcase ) ) . ".";
 
         Sim::OPT::callblock( { countcase => $countcase, countblock => $countblock,
@@ -1043,70 +1189,146 @@ sub descend
       #say $tee "\%datastruc : " . dump( %datastruc );
       #say $tee "\%dowhat : " . dump( %dowhat );
 
-
       if ( $dirfiles{starsign} eq "yes" )
       {
-        say $tee "HERE AGAIN?!";
-        say $tee "HERE \$dirfiles{c} : " . dump( $dirfiles{c} );
-        say $tee "HERE \$#blockelts : " . dump( $#blockelts );
+        #say $tee "HERE AGAIN?!";
+        #say $tee "HERE \$dirfiles{c} : " . dump( $dirfiles{c} );
+        #say $tee "HERE \$#blockelts : " . dump( $#blockelts );
         #if ( $dirfiles{c} == $#blockelts )
         #{
         #say $tee "I AM IN";
 
 
-
-
-        if ( $dirfiles{metamodel} eq "yes" )
+        if ( $dowhat{metamodel} eq "yes" ) # PART ON METAMODELS
         {
           sub cleanres
           {
-            open( ORDRES, "$_") or die;
-            my $cleanordres = $_ . "-cleaned.csv";
+            my ( $sortmixed ) = @_;
+            open( ORDRES, "$sortmixed") or die;
+            my $cleanordres = $sortmixed . "-cleaned.csv";
             my @lines = <ORDRES>;
             close ORDRES;
-
+# PART ON METAMODELS
             open( CLEANORDRES, ">>$cleanordres" ) or die;
-
             foreach my $line ( @lines )
             {
-              $line =~ s/$mypath\/$file// ;
+              $line =~ s/^$mypath\/$file// ;
               $line =~ s/^_// ;
-              $line =~ /(\d+)_-(\d+),(\d+)/ ;
-              $line =~ s/$2// ;
-              $line =~ s/_-// ;
               print CLEANORDRES $line;
             }
             close CLEANORDRES;
             return( $cleanordres );
           }
 
-          sub prepareblank { ;};
-          sub jointwo { ;};
+          sub prepareblank
+          {
+            my ( $varnums_r, $blankfile, $blockelts_r, $bag_r, $file, $mids_r ) = @_;
+            my %varnums = %{ $varnums_r }; #say $tee "IN prepareblank \%varnums : " . dump( \%varnums );
+
+            open( BLANKFILE, ">$blankfile" ) or die;
+            #my @blockels = ( sort { $a <=> $b } ( keys %varnums ) ); say $tee "IN prepareblank1 \@blockels : " . dump( @blockels );
+            my @blockelts = ( sort { $a <=> $b } @{ $blockelts_r } ); #say $tee "IN prepareblank1 \@blockelts : " . dump( @blockelts );
+            my @box = @{ Sim::OPT::toil( \@blockelts, \%varnums, $bag_r ) }; #say $tee "IN prepareblank \@box : " . dump( @box );
+            my @obtaineds = @{ Sim::OPT::flattenbox( \@box ) }; #say $tee "IN prepareblank \@obtaineds : " . dump( @obtaineds );
+            my %mids = %{ $mids_r };
+            my $integrated_r = Sim::OPT::integratebox( \@obtaineds, \%mids, $file ); #say $tee "IN prepareblank \$integrated_r : " . dump( $integrated_r );
+
+            #my @finalbox; say $tee "IN LOOP \$file : " . dump( $file );
+
+            sub cleanthis
+            {
+              my ( $integrated_r, $mypath, $file ) = @_;
+              foreach my $el ( @{ $integrated_r } )
+              { #say $tee "IN LOOP \$el : " . dump( $el ); say $tee "IN LOOP \$el->[0] : " . dump( $el->[0] );
+                $el->[0] =~ s/$mypath// ; #say $tee "IN LOOP \$el->[0] : " . dump( $el->[0] );
+                $el->[0] =~ s/^\/// ; #say $tee "IN LOOP \$el->[0] : " . dump( $el->[0] );
+                $el->[0] =~ s/^$file// ; #say $tee "IN LOOP \$el->[0] : " . dump( $el->[0] );
+                $el->[0] =~ s/^_// ; #say $tee "IN LOOP \$e say $tee "IN LOOP \$el->[0] : " . dump( $el->[0] );l->[0] : " . dump( $el->[0] );
+                $el->[0] =~ s/_$// ;
+                push ( @finalbox, $el->[0] );
+              }
+              @finalbox = uniq( @finalbox );
+              #@finalbox = sort { $a <=> $b } @finalbox;
+              @finalbox = sort @finalbox;
+              return( @finalbox );
+            }
+
+            my @finalbox = cleanthis( $integrated_r, $mypath, $file );
+
+            foreach my $el ( @finalbox )
+            {
+              say BLANKFILE $el;
+            }
+            close BLANKFILE;
+          }
+
+
+          sub jointwo
+          {
+            my ( $cleanordres, $blankfile, $startfile ) = @_;
+            open( BLANKFILE, $blankfile ) or die;
+            my @blanklines = <BLANKFILE>;
+            close BLANKFILE;
+
+            open( CLEANORDRES, $cleanordres ) or die;
+            my @ordlines = <CLEANORDRES>;
+            close CLEANORDRES;
+
+            open( STARTFILE, ">$startfile" ) or die;
+
+            my @newarr;
+            foreach my $blankline ( @blanklines )
+            {
+              chomp $blankline;
+              my $signal = "no";
+              foreach my $ordline ( @ordlines )
+              {
+                chomp $ordline;
+                my @row = split( "," , $ordline );
+                if ( $row[0] =~ /$blankline/ )
+                {
+                  say STARTFILE "$blankline" . "," . "$row[1]" ;
+                  $signal = "yes";
+                }
+              }
+              if ( $signal eq "no" )
+              {
+                say STARTFILE $blankline ;
+              }
+            }
+            close STARTFILE;
+          }
+
           sub givename { ;};
+
           sub writefile { ;};
 
-          my $cleanordres = cleanres( $ordres ); say $tee "IN TAKEOPTIMA1 \$cleanordres : " . dump( $cleanordres );
-          my @blank = @{ prepareblank( \%miditers ) };
-          my @prepared = @{ jointwo( $cleanordres, \@blank ) };
-          my ( $metafill ) = givename( $cleanordtot );
-          my $metafile = "$metafill" . "_meta.csv";
-          my $ordmeta = "$metafill" . "_ordmeta.csv";
-          writefile( $metafill, \@prepared );
-          Sim::OPT::Interlinear( $metafill );
+          my $cleanordres = cleanres( $sortmixed ); #say $tee "IN TAKEOPTIMA1 \$cleanordres : " . dump( $cleanordres );
+          my $blankfile = "$sortmixed" . "_blank.csv";
+
+          my $bit = $file . "_";
+          my @bag =( $bit );
+          #say $tee "BEFORE prepareblank \%mids : " . dump( %mids );
+          prepareblank( $dirfiles{varnumbershold}->[0], $blankfile, \@blockelts, \@bag, $file, \%mids ) ;
+
+          my $startfile = $sortmixed . "_start.csv";
+          jointwo( $cleanordres, $blankfile, $startfile ) ;
 
 
-          open( METAFILE, "$metafile" ) or die;
+          say $tee "ABOUT TO LAUNCH INTERLINEAR";
+          Sim::OPT::Interlinear::interlinear( $confinterlinear, $startfile, $metafile, \@blockelts, $tofile );
+
+          open( METAFILE, "$metafile" ) or die "THERE IS NO METAFILE $metafile!\n";
           my @totlines = <METAFILE>;
           close METAFILE;
 
-
           if ( ( $direction eq "<" ) or ( $starorder eq "<" ) )
           {
-            @sorted = sort { (split( ',', $a))[ 0 ] <=> ( split( ',', $b))[ 0 ] } @totlines;
+            @sorted = sort { (split( ',', $a))[ 1 ] <=> ( split( ',', $b))[ 1 ] } @totlines;
           }
           elsif ( ( $direction eq ">" ) or ( $starorder eq ">" ) )
           {
-            @sorted = sort { (split( ',', $b))[ 0 ] <=> ( split( ',', $a))[ 0 ] } @totlines;
+            @sorted = sort { (split( ',', $b))[ 1 ] <=> ( split( ',', $a))[ 1 ] } @totlines;
           }
 
           open( ORDMETA, ">>$ordmeta" ) or die;
@@ -1115,7 +1337,8 @@ sub descend
             print ORDMETA $ln;
           }
           close ORDMETA;
-        }
+        } # END PART ON METAMODELS
+
 
 
 
@@ -1161,7 +1384,7 @@ sub descend
         }
         chomp $winnerentry;
 
-        push ( @{ $winneritems[$countcase][$countblock] }, $winneritem ); say $tee "IN STARPATH TAKEOPTIMA->\@winneritems " . dump(@winneritems);
+        push ( @{ $winneritems[$countcase][$countblock] }, $winneritem ); #say $tee "IN STARPATH TAKEOPTIMA->\@winneritems " . dump(@winneritems);
         say $tee "#Leaving case " . ( plus1( $countcase ) ) . ", block " . ( plus1( $countcase ) ) . ", and descending!";
 
         @varnumbers = @{ dclone( $dirfiles{varnumbershold} ) };
@@ -1178,10 +1401,8 @@ sub descend
         #}
       }
       else
-      {
-        say $tee "NOW I SHOULD ACT.";
-        push ( @{ $winneritems[$countcase][$countblock] }, $winneritem ); say $tee "IN NORMALPATH TAKEOPTIMA->\@winneritems " . dump(@winneritems);
-        say $tee "NOT STAR-DESCENDING.";
+      { #say $tee "NOW I SHOULD ACT.";
+        push ( @{ $winneritems[$countcase][$countblock] }, $winneritem ); #say $tee "IN NORMALPATH TAKEOPTIMA->\@winneritems " . dump(@winneritems);
         say $tee "#Leaving case " . ( plus1( $countcase ) ) . ", block " . ( plus1( $countcase ) ) . ", and descending!";
 
         $countblock++; ### !!!
@@ -1195,7 +1416,7 @@ sub descend
     }
   } # END SUB takeoptima
 
-  takeoptima( $sortmixed ); say $tee "TAKEOPTIMA \$sortmixed : " . dump( $sortmixed );
+  takeoptima( $sortmixed ); #say $tee "TAKEOPTIMA \$sortmixed : " . dump( $sortmixed );
   close OUTFILE;
   close TOFILE;
 }    # END SUB descend
